emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] trunk r115612: Fix bug #16190 with documentation of capita


From: Eli Zaretskii
Subject: [Emacs-diffs] trunk r115612: Fix bug #16190 with documentation of capitalize-word.
Date: Thu, 19 Dec 2013 17:51:35 +0000
User-agent: Bazaar (2.6b2)

------------------------------------------------------------
revno: 115612
revision-id: address@hidden
parent: address@hidden
fixes bug: http://debbugs.gnu.org/16190
committer: Eli Zaretskii <address@hidden>
branch nick: trunk
timestamp: Thu 2013-12-19 19:51:18 +0200
message:
  Fix bug #16190 with documentation of capitalize-word.
  
   src/casefiddle.c (Fupcase_word, Fdowncase_word, Fcapitalize_word):
   Doc fix.
modified:
  src/ChangeLog                  changelog-20091113204419-o5vbwnq5f7feedwu-1438
  src/casefiddle.c               
casefiddle.c-20091113204419-o5vbwnq5f7feedwu-154
=== modified file 'src/ChangeLog'
--- a/src/ChangeLog     2013-12-19 10:25:48 +0000
+++ b/src/ChangeLog     2013-12-19 17:51:18 +0000
@@ -1,3 +1,8 @@
+2013-12-19  Eli Zaretskii  <address@hidden>
+
+       * casefiddle.c (Fupcase_word, Fdowncase_word, Fcapitalize_word):
+       Doc fix.  (Bug#16190)
+
 2013-12-19  Jan Djärv  <address@hidden>
 
        * nsterm.h (KEY_NS_DRAG_FILE, KEY_NS_DRAG_COLOR, KEY_NS_DRAG_TEXT):

=== modified file 'src/casefiddle.c'
--- a/src/casefiddle.c  2013-11-01 10:00:47 +0000
+++ b/src/casefiddle.c  2013-12-19 17:51:18 +0000
@@ -365,7 +365,11 @@
 }
 
 DEFUN ("upcase-word", Fupcase_word, Supcase_word, 1, 1, "p",
-       doc: /* Convert following word (or ARG words) to upper case, moving 
over.
+       doc: /* Convert to upper case from point to end of word, moving over.
+
+If point is in the middle of a word, the part of that word before point
+is ignored when moving forward.
+
 With negative argument, convert previous words but do not move.
 See also `capitalize-word'.  */)
   (Lisp_Object arg)
@@ -380,7 +384,11 @@
 }
 
 DEFUN ("downcase-word", Fdowncase_word, Sdowncase_word, 1, 1, "p",
-       doc: /* Convert following word (or ARG words) to lower case, moving 
over.
+       doc: /* Convert to lower case from point to end of word, moving over.
+
+If point is in the middle of a word, the part of that word before point
+is ignored when moving forward.
+
 With negative argument, convert previous words but do not move.  */)
   (Lisp_Object arg)
 {
@@ -394,9 +402,14 @@
 }
 
 DEFUN ("capitalize-word", Fcapitalize_word, Scapitalize_word, 1, 1, "p",
-       doc: /* Capitalize the following word (or ARG words), moving over.
+       doc: /* Capitalize from point to the end of word, moving over.
+With numerical argument ARG, capitalize the next ARG-1 words as well.
 This gives the word(s) a first character in upper case
 and the rest lower case.
+
+If point is in the middle of a word, the part of that word before point
+is ignored when moving forward.
+
 With negative argument, capitalize previous words but do not move.  */)
   (Lisp_Object arg)
 {


reply via email to

[Prev in Thread] Current Thread [Next in Thread]